==> flink-1.12.7-src.tgz: flink-1.12.7/flink-runtime-web/src/test/java/org/apache/flink/runtime/webmonitor/handlers/JarUploadResponseBodyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.webmonitor.handlers;

import org.apache.flink.runtime.rest.messages.RestResponseMarshallingTestBase;

import static org.junit.Assert.assertEquals;

/** Tests for {@link JarUploadResponseBody}. */
public class JarUploadResponseBodyTest
        extends RestResponseMarshallingTestBase<JarUploadResponseBody> {

    @Override
    protected Class<JarUploadResponseBody> getTestResponseClass() {
        return JarUploadResponseBody.class;
    }

    @Override
    protected JarUploadResponseBody getTestResponseInstance() throws Exception {
        return new JarUploadResponseBody("/tmp");
    }

    @Override
    protected void assertOriginalEqualsToUnmarshalled(
            final JarUploadResponseBody expected, final JarUploadResponseBody actual) {
        assertEquals(expected.getFilename(), actual.getFilename());
        assertEquals(expected.getStatus(), actual.getStatus());
    }
}

==> flink-1.17.2-src.tgz: flink-1.17.2/flink-runtime-web/src/test/java/org/apache/flink/runtime/webmonitor/handlers/JarUploadResponseBodyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.webmonitor.handlers;

import org.apache.flink.runtime.rest.messages.RestResponseMarshallingTestBase;

import static org.assertj.core.api.Assertions.assertThat;

/** Tests for {@link JarUploadResponseBody}. */
public class JarUploadResponseBodyTest
        extends RestResponseMarshallingTestBase<JarUploadResponseBody> {

    @Override
    protected Class<JarUploadResponseBody> getTestResponseClass() {
        return JarUploadResponseBody.class;
    }

    @Override
    protected JarUploadResponseBody getTestResponseInstance() throws Exception {
        return new JarUploadResponseBody("/tmp");
    }

    @Override
    protected void assertOriginalEqualsToUnmarshalled(
            final JarUploadResponseBody expected, final JarUploadResponseBody actual) {
        assertThat(actual.getFilename()).isEqualTo(expected.getFilename());
        assertThat(actual.getStatus()).isEqualTo(expected.getStatus());
    }
}
